function [NG, cards, inds] = get_datastructures(groups)
% Prepare various group-related data structures used in inference.
%
% Input: groups -- an NG x P binary matrix where, for i=1...NG, the i-th
%        row encodes which of the P variables make up the i-th group
% Output: NG -- a scalar: The number of groups
%         cards -- an NG x 1 vector: the cardinality of each group
%         inds -- an NG x 1 cell array: inds{i} contains an array
%                 of indices of variables contained in the i-th group  
%
% Copyright 2014 Nino Shervashidze    
    
    NG = size(groups,1);
    cards = sum(groups, 2); 
    inds = cell(NG,1); 
    for g=1:NG
        inds{g}=find(groups(g,:));
    end
end
